# crosstab

[![ci/cd](https://github.com/geocoug/crosstab/actions/workflows/ci-cd.yml/badge.svg)](https://github.com/geocoug/crosstab/actions/workflows/ci-cd.yml)
[![Documentation Status](https://readthedocs.org/projects/pg-upsert/badge/?version=latest)](https://pg-upsert.readthedocs.io/en/latest/?badge=latest)
[![PyPI Latest Release](https://img.shields.io/pypi/v/crosstab.svg)](https://pypi.org/project/crosstab/)
[![PyPI Downloads](https://img.shields.io/pypi/dm/crosstab.svg?label=pypi%20downloads)](https://pypi.org/project/crosstab/)
[![Python Version Support](https://img.shields.io/pypi/pyversions/crosstab.svg)](https://pypi.org/project/crosstab/)

**crosstab** is a Python package that rearranges data from a normalized CSV format to a crosstabulated format, with styling.

## Installation

You can install **crosstab** via pip from PyPI:

```bash
pip install crosstab
```

There is also a Docker image available on the GitHub Container Registry:

```bash
docker pull ghcr.io/geocoug/crosstab:latest
```
